.. _api-ref:

*************
API reference
*************

.. note:: What is public?

    Only APIs documented here are public and open for use by Mopidy
    extensions.


.. toctree::
    :glob:

    concepts
    models
    backends
    core
    audio
    mixer
    frontends
    commands
    ext
    config
    zeroconf
    http-server
    http
    js
